@@ -30,7 +30,7 @@ standardize_imported_function <- function(fun) {
     fun <- ignore_ignore(fun)
     str <- safe_deparse(fun) # Worth it: ignore_ignore is slow.
   }
-  str
+  gsub("<pointer: 0x[0-9a-zA-Z]*>", "", str)
 }
 
 ignore_ignore <- function(x) {
