@@ -2,6 +2,24 @@ if (FALSE) {
 
 drake_context("always skipped")
 
+test_with_dir("use_drake()", {
+  # Load drake with library(drake)
+  # and not with devtools::load_all().
+  # Reason: https://github.com/r-lib/usethis/issues/347
+  # If that problem is ever solved, we should move this test
+  # to tests/testthat/test-examples.R.
+  skip_if_not_installed("usethis")
+  usethis::create_project(".", open = FALSE, rstudio = FALSE)
+  files <- c("make.R", "_drake.R")
+  for (file in files) {
+    expect_false(file.exists(file))
+  }
+  use_drake(open = FALSE)
+  for (file in files) {
+    expect_true(file.exists(file))
+  }
+})
+
 test_with_dir("can keep going in parallel", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   plan <- drake_plan(
@@ -9,7 +27,7 @@ test_with_dir("can keep going in parallel", {
     b = a + 1
   )
   make(
-    plan, jobs = 2, session_info = FALSE, keep_going = TRUE, verbose = FALSE)
+    plan, jobs = 2, session_info = FALSE, keep_going = TRUE, verbose = 0L)
   expect_error(readd(a))
   expect_equal(readd(b), numeric(0))
 })
@@ -17,19 +35,20 @@ test_with_dir("can keep going in parallel", {
 test_with_dir("drake_debug()", {
   skip_on_cran()
   load_mtcars_example()
-  my_plan$command[2] <- "simulate(48); stop(1234)"
+  my_plan$command[[2]] <- quote({
+    simulate(48)
+    stop(1234)
+  })
   config <- drake_config(my_plan, lock_envir = TRUE)
   expect_error(make(my_plan), regexp = "1234")
   out <- drake_debug(large, config = config)
   out <- drake_debug(
-    "large", config = config, verbose = "false", character_only = TRUE)
-  expect_true(is.data.frame(out))
-  my_plan$command <- lapply(
-    X = as.list(my_plan$command),
-    FUN = function(x) {
-      parse(text = x)[[1]]
-    }
+    "large",
+    config = config,
+    verbose = 0L,
+    character_only = TRUE
   )
+  expect_true(is.data.frame(out))
   for (i in 1:2) {
     clean(destroy = TRUE)
     load_mtcars_example()
@@ -95,18 +114,50 @@ test_with_dir("make() in interactive mode", {
   expect_equal(cached(), sort(my_plan$target))
   expect_equal(sort(outdated(config)), character(0))
   expect_equal(sort(justbuilt(config)), sort(my_plan$target))
-  clean()
+  clean() # Select 1.
   .pkg_envir$drake_make_menu <- NULL
   make(my_plan) # Select 1.
   expect_equal(cached(), sort(my_plan$target))
   expect_equal(sort(outdated(config)), character(0))
   expect_equal(sort(justbuilt(config)), sort(my_plan$target))
-  clean()
+  clean() # No menu
   .pkg_envir$drake_make_menu <- NULL
   options(drake_make_menu = FALSE)
   make(my_plan) # No menu.
   expect_equal(sort(outdated(config)), character(0))
   expect_equal(sort(justbuilt(config)), sort(my_plan$target))
+  unlink(".drake", recursive = TRUE)
+  .pkg_envir$drake_make_menu <- NULL
+  options(drake_make_menu = TRUE)
+  make(my_plan) # Select 0.
+  expect_equal(sort(outdated(config)), sort(my_plan$target))
+  expect_equal(sort(justbuilt(config)), character(0))
+})
+
+test_with_dir("clean() in interactive mode", {
+  # Must run this test in a fresh new interactive session.
+  # Cannot be fully automated like the other tests.
+  load_mtcars_example()
+  config <- drake_config(my_plan)
+  make(my_plan) # Select 1.
+  expect_equal(sort(cached()), sort(my_plan$target))
+  clean() # Select 2.
+  expect_equal(sort(cached()), sort(my_plan$target))
+  .pkg_envir$drake_clean_menu <- NULL
+  clean() # Select 0.
+  expect_equal(sort(cached()), sort(my_plan$target))
+  .pkg_envir$drake_clean_menu <- NULL
+  clean() # Select 1.
+  expect_equal(sort(cached()), character(0))
+  make(my_plan)
+  expect_equal(sort(cached()), sort(my_plan$target))
+  clean() # No menu.
+  expect_equal(sort(cached()), character(0))
+  make(my_plan)
+  .pkg_envir$drake_clean_menu <- NULL
+  options(drake_clean_menu = FALSE)
+  clean() # No menu.
+  expect_equal(sort(cached()), character(0))
 })
 
 test_with_dir("r_make() + clustermq", {
