@@ -7,6 +7,7 @@ test_with_dir("future package functionality", {
   scenario <- get_testing_scenario()
   e <- eval(parse(text = scenario$envir))
   load_mtcars_example(envir = e)
+  e$my_plan$hpc <- e$my_plan$target != "regression1_large"
   backends <- rep("future", 2)
   caching <- c("master", "worker")
   for (i in seq_along(backends)) {
@@ -17,7 +18,7 @@ test_with_dir("future package functionality", {
       parallelism = backends[i],
       caching = caching[i],
       jobs = 1,
-      verbose = FALSE,
+      verbose = 0L,
       session_info = FALSE,
       lock_envir = TRUE
     )
@@ -27,7 +28,7 @@ test_with_dir("future package functionality", {
       parallelism = backends[i],
       caching = caching[i],
       jobs = 1,
-      verbose = FALSE,
+      verbose = 0L,
       session_info = FALSE,
       lock_envir = TRUE
     )
@@ -44,7 +45,7 @@ test_with_dir("future package functionality", {
       parallelism = backends[i],
       caching = caching[i],
       jobs = 1,
-      verbose = FALSE,
+      verbose = 0L,
       session_info = FALSE,
       lock_envir = TRUE
     )
@@ -59,7 +60,7 @@ test_with_dir("future package functionality", {
       parallelism = backends[i],
       caching = caching[i],
       jobs = 1,
-      verbose = FALSE,
+      verbose = 0L,
       session_info = FALSE,
       lock_envir = TRUE
     )
@@ -69,7 +70,7 @@ test_with_dir("future package functionality", {
       parallelism = backends[i],
       caching = caching[i],
       jobs = 1,
-      verbose = FALSE,
+      verbose = 0L,
       session_info = FALSE,
       lock_envir = TRUE
     )
@@ -90,7 +91,7 @@ test_with_dir("future package functionality", {
       parallelism = backends[i],
       caching = caching[i],
       jobs = 2,
-      verbose = FALSE,
+      verbose = 0L,
       session_info = FALSE,
       ensure_workers = FALSE
     )
